<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Contact;
use Illuminate\Support\Facades\DB;
use phpDocumentor\Reflection\Types\Context;

class ContactController extends Controller
{
    public function __construct()
    {
        $this->middleware([ "auth" ]);
        $this->middleware([ "lang" ]);

        $this->middleware([ "check.auth:contact.show" ])->only("show", "index");
        $this->middleware([ "check.auth:contact.create" ])->only("create", "store");
        $this->middleware([ "check.auth:contact.edit" ])->only("edit", "update");
        $this->middleware([ "check.auth:contact.delete" ])->only("delete");
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $contact = Contact::query()->get();

        return Response::detect("contacts.index", [ "contacts" => $contact]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return Response::detect("contacts.create");

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $requestContact = $request->validate([
            "contactname" => "required|max:255",
            "title" => "required|max:255",
            "email" => "required|max:255",
            "phone" => "max:255",
        ]);

        $contact = new Contact($requestContact);
        $contact->phonetimes = $request->phonetimes;
        $saved = $contact->save();

        if(!$saved){
            return redirect()->route("contacts.store");
        }else{
            $contact = Contact::query()->get();
            return redirect()->route("contacts.index", ['contacts' => $contact]);
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        return Response::detect("contacts.show", [ "contacts" => $id]);

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $contact = Contact::find($id);
        return Response::detect("contacts.edit", ["contact" => $contact]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $data = $request->all();
        $contact = Contact::find($id);
        $contact->update($data);
        $saved = $contact->save();

        if(!$saved){
            return redirect()->route("contacts.update", [ "contacts" => $contact ]);
        }else{
            $contact = Contact::query()->get();
            return redirect()->route("contacts.index", ['contacts' => $contact]);
        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $contact = Contact::find($id);
        $contact->delete();
        return redirect()->route("contacts.index");
    }
}
