<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;
use Illuminate\Database\Eloquent\Collection;

class RolesController extends Controller
{
    public function __construct()
    {
        $this->middleware([ "auth" ]);
        $this->middleware([ "lang" ]);

        $this->middleware([ "check.auth:roles.show" ])->only("show", "index");
        $this->middleware([ "check.auth:roles.create" ])->only("create", "store");
        $this->middleware([ "check.auth:roles.edit" ])->only("edit", "update");
        $this->middleware([ "check.auth:roles.delete" ])->only("delete");
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        //$roles = Role::query()->where("id", "!=", 1)->where("id", "!=", 2)->get(); Add this bitch if the users isn't allowed to se the rolls with id 1 and 2
        $roles = Role::query()->get();

        return Response::detect("roles.index", [ "roles" => $roles]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return Response::detect("roles.create");
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $requestRole = $request->validate([
            "name" => "required|max:255",
            "description" => "required|max:255"
        ]);

        $brugerPermissions = new Collection();
        if ($request->value !== null) {
            foreach ($request->value as $valuee) {
                $brugerPermissions->add(\Spatie\Permission\Models\Permission::query()->where("name", "=", $valuee)->first());
            }
        }

        $role = new Role($requestRole);

        $allRoles = Role::query()->where('name', '=', $request->name)->get();

        // If there already is a role with that name, then don't create
        if(count($allRoles) > 0)
            return redirect()->route("roles.store");
        else { // Else - Create it
            $role->save();

            if (!$brugerPermissions->isEmpty()) {
                foreach ($brugerPermissions as $permission) {
                    \Spatie\Permission\Models\Role::query()->find($role->id)->givePermissionTo($permission);
                }
            }

            $roles = Role::query()->get();
            return redirect()->route("roles.index", ['roles' => $roles]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        return Response::detect("roles.show", [ "role" => $id]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //Disables editing of roles: Administrator & Bruger
        if($id == 1 || $id == 2)
            return redirect()->route("roles.index");

        $role = Role::find($id);
        return Response::detect("roles.edit", ["role" => $role]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if($id == 1 || $id == 2)
            return redirect()->route("roles.index");

        $data = $request->validate([
            "name" => "required|max:255",
            "description" => "required|max:255"
        ]);
        $role = Role::find($id);

        $brugerPermissions = new Collection();
        if ($request->value !== null) {
            foreach ($request->value as $valuee) {
                $brugerPermissions->add(Permission::query()->where("name", "=", $valuee)->first());
            }
        }

        // Delete all permission to the role you're editing, so you can give new ones
        foreach (Permission::query()->get() as $permission) {
            Role::query()->find($id)->revokePermissionTo($permission);
        }

        // Give new permissions to the tole you're editing
        if (!$brugerPermissions->isEmpty()) {
            foreach ($brugerPermissions as $permission) {
                Role::query()->find($id)->givePermissionTo($permission);
            }
        }

        $allRoles = Role::query()->where('name', '=', $request->name)->where('id', '!=', $id)->get();

        //Check if role already exist if not save
        if(count($allRoles) > 0){
            return redirect()->route("roles.index", [ "role" => $role ]);
        }else{
            $role->update($data);
            $role->save();

            $roles = Role::query()->get();
            return redirect()->route("roles.index", ['roles' => $roles]);
        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //Disables deletion of roles: Administrator & Bruger
        if($id == 1 || $id == 2)
            return redirect()->route("roles.index");

        $role = Role::find($id);
        $role->delete();
        return redirect()->route("roles.index");
    }

    //Used for checking if the currently typed role name is unique. Create version
    public function nameCheck(Request $request){
        $roles = Role::query()->where('name', 'LIKE',$request->nameCheck)->get();
        if(count($roles) > 0 && $request->nameCheck !== NULL){
            return 1;
        }
    }

    //Used for checking if the currently typed role name is unique. Edit version
    public function nameCheckUpdate(Request $request){
        $roles = Role::query()->where('name', 'LIKE',$request->nameCheck)->where('id', '!=', $request->id)->get();
        if(count($roles) > 0 && $request->nameCheck !== NULL){
            return 1;
        }
    }
}
