@extends("admin.layout.base")
@extends("admin.layout.header")

@section("title")
    Kontakt - Vis
@endsection

@section("path")
    <a href="{{ route('contacts.index', [ 'contacts' => $contacts ]) }}" class="text-white">Vis Kontakter</a> /
@endsection

@section("content")
    <style>
        .letterSpaceTable{
            letter-spacing: 1.2px;
        }
    </style>
    <div class="row align-items-center">
        @if(auth()->user()->can('contact.create'))
            <a class="btn btn-inline btn-sde-blue mb-0" href="{{ route('contacts.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret Kontakt</a>
        @endif
    </div>
    <table class="tbl mt-2 letterSpaceTable fixOverflow" id="table_id">
        <thead>
            <th>Kontakt Navn</th>
            <th>Titel</th>
            <th>E-mail</th>
            <th>Tlf</th>
            @if(auth()->user()->can('contact.edit'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/pencil.svg') }}" alt="Update"></th>
            @endif
            @if(auth()->user()->can('contact.delete'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/trashcan.svg') }}" alt="Delete"></th>
            @endif
        </thead>
        <tbody>
            @foreach($contacts as $contact)
                <tr id="row_{{ $contact->id }}">
                    <td>{{ $contact->contactname }}</td>
                    <td>{{ $contact->title }}</td>
                    <td>{{ $contact->email }}</td>
                    <td>{{ $contact->phone }}</td>
                    @if(auth()->user()->can('contact.edit'))
                        <td><a href="{{ route("contacts.edit", [ "contact" => $contact ]) }}"><img class="w-100" src="{{ asset('/images/icons/pencil-dark.svg') }}" alt="Update"></a></td>
                    @endif
                    @if(auth()->user()->can('contact.delete'))
                        <td>
                            @csrf
                            <button class="w-100 nostyle" onclick="delete_contact({{ $contact->id }})"><img class="w-100 cursor-pointer" src="{{ asset('/images/icons/trashcan-dark.svg') }}" alt="Delete"></button>
                        </td>
                    @endif
                </tr>
            @endforeach
        </tbody>
    </table>
@endsection
@section('scripts')
    <script>
        $(document).ready( function () {
            $('#table_id').DataTable({
                columnDefs: [
                    { orderable: false, targets: [-1, -2] }
                ]
            });
        });

        function delete_contact(id) {
            var token = $("input[name='_token']").val();

            Swal.fire({
                title: 'Er du sikker?',
                text: "Dette kan ikke blive ændret tilbage!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Slet Kontakten',
                cancelButtonText: 'Annuller'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: "contacts/"+id,
                        data:{'_token':token, _method: 'DELETE'},
                        success: function () {
                            $('#table_id').DataTable().row($('#row_'+id)[0]).remove().draw();

                            Swal.fire(
                                'Kontakten er slettet!',
                                '',
                                'success'
                            )
                        },
                        error:function (data) {
                            console.log(data);
                        }
                    });
                }
            })
        }
    </script>
@endsection
