@extends("admin.layout.base")
@extends("admin.layout.header")

@section("title")
    Vejledning - Rediger
@endsection

@section("path")
    <a href="{{route('guides.edit', ['guide' => $guide])}}" class="text-white">Rediger vejledning</a> /
@endsection

@section("content")
    <style>
        .toggle__label::before, .toggle__label::after {
            border-color: black;
        }
        .toggle__text::before {
            border-color: black;
        }

        #editor {
            margin-bottom: 1rem;
        }
    </style>
    <link href="{{ asset("/css/quill/quill.snow.css") }}" rel="stylesheet">
    <h1>Rediger vejledning:</h1>
    <form method="post" action="{{route("guides.update", ["guide" => $guide])}}" enctype="multipart/form-data">
        @csrf
        @method("PUT")
        <label for="title">Navn</label>
        <label hidden id="error" for="errormesseages">Navn findes allerede</label>
        <input value="{{$guide->name}}" type="text" name="name" id="title" required>
        <div>
            <select name="guide_category_id" id="guidesCategory" required>
                <option disabled selected value> -- Vælg en kategori -- </option>
                @foreach(\App\GuidesCategory::query()->get() as $guideCategory)
                    {{ $selected = "" }}
                    @if($guide->guide_category_id == $guideCategory->id)
                        {{ $selected = "selected" }}
                    @endif
                    <option {{ $selected }} value="{{ $guideCategory->id }}">{{ $guideCategory->guidesCategoryName }}</option>
                @endforeach
            </select> <label>Vælg en kategori</label>
            <a class="btn btn-inline btn-sde-blue mb-0 ml-1" href="{{ route('guides-category.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret kategori</a>
        </div>
        <label for="editor">Vejledning</label>
        <small class="form-text text-muted">For at kunne indsætte et link, skal du markere den text du vil lave som et link først.</small>
        <div id="editor">{!! $guide->guide_articles !!}</div>
        <textarea name="guide_articles" class="d-none" id="hiddenArea"></textarea>
        <label id="fileuploadee"for="fileuploade">Baggrundsbillede (Forbliv tom hvis billede ikke skal ændres):</label>
        <input id="fileuploade" type="file" name="resource" accept="image/*" value="{{$guide->resource_id}}">
        <label class="toggle">
            <input class="toggle__input" type="checkbox" name="newsoption">
            <span class="toggle__label">
                    <span class="toggle__text">Opdater / Opret som nyhed?</span>
                </span>
        </label>
        <input id="disable" type="submit" class="btn btn-dark text-white" value="Rediger">
    </form>

    <script src="{{ asset("/js/quill/quill.js") }}"></script>
    <script>
        var container = document.getElementById("editor");
        var fullEditor = new Quill(container, {
            modules: {
                'toolbar': [
                    [ 'bold', 'italic', 'underline', 'strike' ],
                    [{ 'color': [] }],
                    [{ 'script': 'super' }, { 'script': 'sub' }],
                    [{ 'header': '1' }, { 'header': '2' }, 'blockquote' ],
                    [{ 'list': 'ordered' }, { 'list': 'bullet'}, { 'indent': '-1' }, { 'indent': '+1' }],
                    [ {'direction': 'rtl'}, { 'align': [] }],
                    [ 'link', 'image', 'video' ],
                    [ 'clean' ]
                ],
            },
            theme: 'snow'
        });
    </script>
    <script>
        var form = document.querySelector('form');
        form.onsubmit = function() {
            var myEditor = document.getElementById('editor');
            var html = myEditor.children[0].innerHTML;
            document.getElementById('hiddenArea').innerText = html;
        }
    </script>
@endsection
@section("scripts")
    <script>
        $(function() {
            $('form').areYouSure(
                {
                    message: 'It looks like you have been editing something. '
                        + 'If you leave before saving, your changes will be lost.'
                }
            );
        });

        $(document).ready(function () {
            $value = $('#title').val();
            console.log($value);
            $.ajax({
                type: 'get',
                url: '{{route('guides.nameCheckUpdate')}}',
                data: {'nameCheck':$value, 'id':{{$guide->id}}},
                success:function (data) {
                    console.log(data);
                    if(data){
                        $("#error").show(100);
                        $("#error").css('color', 'red');
                        $("#disable").prop('disabled', true);
                        $('#disable').css('cursor','not-allowed');
                    }else{
                        $("#error").hide();
                        $("#disable").prop('disabled', false);
                        $('#disable').css('cursor','pointer');
                    }

                },
                error:function (data) {
                    console.log(data);
                }
            });
        });

        $('#title').on('keyup', function () {
            $value = $(this).val();
            $.ajax({
                type: 'get',
                url: '{{route('guides.nameCheckUpdate')}}',
                data: {'nameCheck':$value, 'id':{{$guide->id}}},
                success:function (data) {
                    if(data){
                        $("#error").show(100);
                        $("#error").css('color', 'red');
                        $("#disable").prop('disabled', true);
                        $('#disable').css('cursor','not-allowed');
                    }else{
                        $("#error").hide();
                        $("#disable").prop('disabled', false);
                        $('#disable').css('cursor','pointer');
                    }

                },
                error:function (data) {
                    console.log(data);
                }
            });
        })
    </script>
@endsection
