@extends("admin.layout.base")
@extends("admin.layout.header")

@section("title")
    Menuplan - Vis
@endsection

@section("path")
    <a href="{{ route('menu-plans.index') }}" class="text-white">Vis Menuplan</a> /
@endsection

@section("content")
    <style>
        .letterSpaceTable{
            letter-spacing: 1.2px;
        }
    </style>
    <script src="{{ asset("/js/jquery-3.2.1.min.js") }}"></script>
    @if(auth()->user()->can('menuplan.create'))
        <div class="row align-items-center">
            <a class="btn btn-inline btn-sde-blue mb-0" href="{{ route('menu-plans.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret Menuplan</a>
        </div>
    @endif

    <table class="tbl letterSpaceTable" id="table_id">
        <thead>
            <th>Uge</th>
            <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/preview.svg') }}" alt="preview"></th>
            <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/print-hvid.svg') }}" alt="Print"></th>
            @if(auth()->user()->can('menuplan.edit'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/pencil.svg') }}" alt="Update"></th>
            @endif
            @if(auth()->user()->can('menuplan.delete'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/trashcan.svg') }}" alt="Delete"></th>
            @endif
        </thead>
        <tbody>
            @foreach($menuPlans as $menuplan)
            <tr id="row_{{ $menuplan->id }}">
                <td>{{$menuplan->week}}</td>
                <td><a id="preview" onclick="modalMenuContent({{$menuplan->id}})" style="cursor: pointer" ><img class="w-100" src="{{ asset('/images/icons/preview-dark.svg') }}" alt="preview"></a></td>
                <td><a href="{{ route("pdf.genPDF", [ "menuPlan" => $menuplan ]) }}" target="_blank"><img class="w-100" src="{{ asset('/images/icons/print.svg') }}" alt="Print"></a></td>
                @if(auth()->user()->can('menuplan.edit'))
                    <td><a href="{{ route("menu-plans.edit", [ "menu_plan" => $menuplan ]) }}"><img class="w-100" src="{{ asset('/images/icons/pencil-dark.svg') }}" alt="Update"></a></td>
                @endif
                @if(auth()->user()->can('menuplan.delete'))
                    <td>
                        @csrf
                        <a class="w-100 nostyle" onclick="delete_menu({{ $menuplan->id }})"><img class="w-100 cursor-pointer" src="{{ asset('/images/icons/trashcan-dark.svg') }}" alt="Delete"></a>
                    </td>
                @endif
            </tr>
            @endforeach
        </tbody>
    </table>

    <div id="menuModal" class="modal zindex-100">
        <div id="modal-content" class="modal-content text-black d-block w-50">
            <span class="close" onclick="closeModal()">&times;</span>
            <center>
                <h1 id="week"></h1>
                <hr>
                <strong><label for="monday">Mandag</label></strong>
                <p id="monday"></p>
                <strong><label for="tuesday">Tirsdag</label></strong>
                <p id="tuesday"></p>
                <strong><label for="wednesday">Onsdag</label></strong>
                <p id="wednesday"></p>
                <strong><label for="thursday">Torsdag</label></strong>
                <p id="thursday"></p>
            </center>
        </div>
    </div>
@endsection
@section('scripts')
    <script>
        var modalMenu = document.getElementById("menuModal");

        function modalMenuContent(id) {
            $.ajax({
                type: 'get',
                url: '{{route('menuplans.preview')}}',
                data: {'preview':id},
                success:function (data) {
                    modalNews.style.display = "flex";
                    var l = JSON.parse(data);
                    $("#week").html("Menuplan for uge " + l.week);
                    $("#monday").html(l.monday);
                    $("#tuesday").html(l.tuesday);
                    $("#wednesday").html(l.wednesday);
                    $("#thursday").html(l.thursday);
                },
                error:function (data) {
                    console.log(data);
                }
            });
        }

        function closeModal() {
            modalMenu.style.display = "none";
            $("#week").html('');
            $("#monday").html('');
            $("#tuesday").html('');
            $("#wednesday").html('');
            $("#thursday").html('');
        }

        window.onmousedown = function(event) {
            if (event.target == modalMenu) {
                modalMenu.style.display = "none";
                $("#week").html('');
                $("#monday").html('');
                $("#tuesday").html('');
                $("#wednesday").html('');
                $("#thursday").html('');
            }
        }
    </script>
    <script>
        $(document).ready( function () {
            $('#table_id').DataTable({
                columnDefs: [
                    { orderable: false, targets: [-1, -2, -3, -4] }
                ]
            });
        });

        function delete_menu(id) {
            var token = $("input[name='_token']").val();

            Swal.fire({
                title: 'Er du sikker?',
                text: "Dette kan ikke blive ændret tilbage!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Slet Menuplanen',
                cancelButtonText: 'Annuller'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: "menu-plans/"+id,
                        data:{'_token':token, _method: 'DELETE'},
                        success: function () {
                            $('#table_id').DataTable().row($('#row_'+id)[0]).remove().draw();

                            Swal.fire(
                                'Menuplanen er slettet!',
                                '',
                                'success'
                            )
                        },
                        error:function (data) {
                            console.log(data);
                        }
                    });
                }
            })
        }
    </script>
@endsection
