@extends("admin.layout.base")
@extends("admin.layout.header")

@section("title")
    Rolle - Vis
@endsection

@section("path")
    <a href="{{ route('roles.index') }}" class="text-white">Vis Roller</a> /
@endsection

@section("content")
    <style>
        .letterSpaceTable{
            letter-spacing: 1.2px;
        }
    </style>
    <div class="row align-items-center">
        @if(auth()->user()->can('roles.create'))
            <a class="btn btn-inline btn-sde-blue mb-0" href="{{ route('roles.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret Rolle</a>
        @endif
    </div>
    <table class="tbl mt-2 letterSpaceTable" id="table_id">
        <thead>
            <th>Navn</th>
            <th>Beskrivelse</th>
            @if(auth()->user()->can('roles.edit'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/pencil.svg') }}" alt="Update"></th>
            @endif
            @if(auth()->user()->can('roles.delete'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/trashcan.svg') }}" alt="Delete"></th>
            @endif
        </thead>
        <tbody>
            @foreach($roles as $role)
                <tr id="row_{{ $role->id }}">
                    <td>{{ $role->name }}</td>
                    <td>{{ $role->description }}</td>
                    @if(auth()->user()->can('roles.edit'))
                        <td><a href="{{ route("roles.edit", [ "role" => $role->id ]) }}"><img class="w-100" src="{{ asset('/images/icons/pencil-dark.svg') }}" alt="Update"></a></td>
                    @endif
                    @if(auth()->user()->can('roles.delete'))
                        <td>
                            @csrf
                            <a class="w-100 nostyle" onclick="delete_role({{ $role->id }})"><img class="w-100 cursor-pointer" src="{{ asset('/images/icons/trashcan-dark.svg') }}" alt="Delete"></a>
                        </td>
                    @endif
                </tr>
            @endforeach
        </tbody>
    </table>
@endsection
@section('scripts')
    <script>
        $(document).ready( function () {
            $('#table_id').DataTable({
                columnDefs: [
                    { orderable: false, targets: [-1, -2] }
                ]
            });
        });

        function delete_role(id) {
            var token = $("input[name='_token']").val();

            Swal.fire({
                title: 'Er du sikker?',
                text: "Dette kan ikke blive ændret tilbage!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Slet Rollen',
                cancelButtonText: 'Annuller'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: "roles/"+id,
                        data:{'_token':token, _method: 'DELETE'},
                        success: function () {
                            if (id == 1) {
                                Swal.fire(
                                    'Administrator rollen kan ikke slettes',
                                    '',
                                    'warning'
                                )
                            } else if (id == 2) {
                                Swal.fire(
                                    'Bruger rollen kan ikke slette',
                                    '',
                                    'warning'
                                )
                            } else {
                                $('#table_id').DataTable().row($('#row_'+id)[0]).remove().draw();

                                Swal.fire(
                                    'Rollen er slettet!',
                                    '',
                                    'success'
                                )
                            }
                        },
                        error:function (data) {
                            console.log(data);
                        }
                    });
                }
            })
        }
    </script>
@endsection
