@extends("admin.layout.base")
@extends("admin.layout.header")

@section("title")
    Vaskemaskiner - Vis
@endsection

@section("path")
    <a href="{{ route('washing-machines.index') }}" class="text-white">Vis Vaskemaskiner</a> /
@endsection

@section("content")
    <style>
        .letterSpaceTable{
            letter-spacing: 1.2px;
        }
    </style>
    <div class="row align-items-center">
        @if(auth()->user()->can('washing.machine.create'))
            <a class="btn btn-inline btn-sde-blue mb-0" href="{{ route('washing-machines.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret Vaskemaskine</a>
        @endif
        @if(auth()->user()->can('locations.create'))
                <a class="btn btn-inline btn-sde-blue mb-0 ml-1" href="{{ route('locations.create') }}"><img src="{{ asset('/images/icons/plus.svg') }}" alt="Create">Opret Vaskemaskine lokation</a>
        @endif
        <div class="mt-1 ml-1">
            <select name="risRosName" id="locationID">
                <option selected="selected" name="all" value="all">Alle</option>
                @foreach(\App\Location::query()->get() as $location)
                    <option value="{{$location->id}}">{{$location->name}}</option>
                @endforeach
            </select> <label>Vælg bygning</label>
        </div>
    </div>
    <div id="searchWashingMachine" class="mt-2">
        <label>Vaskemaskiner</label>
    <table id="washingSearch" class="tbl letterSpaceTable fixOverflow">
        <thead>
            <th>Navn</th>
            <th>Lokation</th>
            @if(auth()->user()->can('washing.machine.edit'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/pencil.svg') }}" alt="Update"></th>
            @endif
            @if(auth()->user()->can('washing.machine.delete'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/trashcan.svg') }}" alt="Delete"></th>
            @endif
        </thead>
        @foreach($machines as $machine)
        <tr id="machine_row_{{ $machine->id }}">
            <td>{{$machine->name}}</td>
            <td>{{\App\Location::query()->where("id", "=", $machine->location_id)->first()->name}}</td>
            @if(auth()->user()->can('washing.machine.edit'))
                <td><a href="{{ route('washing-machines.edit', [ 'washing_machine' => $machine ]) }}"><img class="w-100" src="{{ asset('/images/icons/pencil-dark.svg') }}" alt="Update"></a></td>
            @endif
            @if(auth()->user()->can('washing.machine.delete'))
                <td>
                    @csrf
                    <a class="w-100 nostyle" onclick="delete_machine({{ $machine->id }})"><img class="w-100 cursor-pointer" src="{{ asset('/images/icons/trashcan-dark.svg') }}" alt="Delete"></a>
                </td>
            @endif
        </tr>
        @endforeach
    </table>
    </div>

    <div id="locations" class="mt-2">
    <label>Vaskemaskine lokation</label>
    <table class="tbl">
        <thead>
            <th>Navn</th>
            <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/eye.svg') }}" alt="Show"></th>
            @if(auth()->user()->can('locations.edit'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/pencil.svg') }}" alt="Update"></th>
            @endif
            @if(auth()->user()->can('locations.delete'))
                <th class="w-1em"><img class="w-100" src="{{ asset('/images/icons/trashcan.svg') }}" alt="Delete"></th>
            @endif
        </thead>
        @foreach(\App\Location::query()->get() as $location)
            <tr id="location_row_{{ $location->id }}">
                <td>{{$location->name}}</td>
                <td><a href="{{ route("locations.show", [ "location" => $location ]) }}"><img class="w-100" src="{{ asset('/images/icons/eye-dark.svg') }}" alt="Show"></a></td>
                @if(auth()->user()->can('locations.edit'))
                    <td><a href="{{ route("locations.edit", [ "location" => $location ]) }}"><img class="w-100" src="{{ asset('/images/icons/pencil-dark.svg') }}" alt="Update"></a></td>
                @endif
                @if(auth()->user()->can('locations.delete'))
                    <td>
                        @csrf
                        <a class="w-100 nostyle" onclick="delete_location({{ $location->id }})"><img class="w-100 cursor-pointer" src="{{ asset('/images/icons/trashcan-dark.svg') }}" alt="Delete"></a>
                    </td>
                @endif
            </tr>
        @endforeach
    </table>
    </div>


    <script>
        $('#locationID').change(function () {
            $value = $('#locationID').find(":selected").val();
            console.log($value);
            $.ajax({
                type: 'get',
                url: '{{route('washing-machines.search')}}',
                data: {'option':$value},
                success:function (data) {
                    $('#washingSearch').html(data);
                },
                error:function (data) {
                    console.log(data);
                }
            });
        })
    </script>
@endsection
@section('scripts')
    <script>
        function delete_machine(id) {
            var token = $("input[name='_token']").val();

            Swal.fire({
                title: 'Er du sikker?',
                text: "Dette kan ikke blive ændret tilbage!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Slet Vaskemaskine',
                cancelButtonText: 'Annuller'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: "washing-machines/"+id,
                        data:{'_token':token, _method: 'DELETE'},
                        success: function () {
                            $('#machine_row_'+id).remove();

                            Swal.fire(
                                'Vaskemaskinen er slettet!',
                                '',
                                'success'
                            )
                        },
                        error:function (data) {
                            console.log(data);
                        }
                    });
                }
            })
        }

        function delete_location(id) {
            var token = $("input[name='_token']").val();

            Swal.fire({
                title: 'Er du sikker?',
                text: "Dette kan ikke blive ændret tilbage!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Slet Lokation',
                cancelButtonText: 'Annuller'
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        type: "POST",
                        url: "locations/"+id,
                        data:{'_token':token, _method: 'DELETE'},
                        success: function () {
                            $('#location_row_'+id).remove();

                            location.reload();
                        },
                        error:function (data) {
                            console.log(data);
                        }
                    });
                }
            })
        }
    </script>
@endsection
